==> insighttoolkit_3.16.0.orig.tar.gz: insighttoolkit-3.16.0/Code/Algorithms/itkWatershedMiniPipelineProgressCommand.cxx <==
/*=========================================================================

  Program:   Insight Segmentation & Registration Toolkit
  Module:    $RCSfile: itkWatershedMiniPipelineProgressCommand.cxx,v $
  Language:  C++
  Date:      $Date: 2009-05-12 20:21:46 $
  Version:   $Revision: 1.5 $

  Copyright (c) Insight Software Consortium. All rights reserved.
  See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.

     This software is distributed WITHOUT ANY WARRANTY; without even 
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
     PURPOSE.  See the above copyright notices for more information.

=========================================================================*/
#include "itkWatershedMiniPipelineProgressCommand.h"


namespace itk {

void WatershedMiniPipelineProgressCommand
::Execute(Object *caller, const EventObject &event)
{
  ProcessObject *po = dynamic_cast<ProcessObject *>(caller);
  if (! po) return;
  
  if( typeid(event) == typeid ( ProgressEvent)  )
    {
    m_Filter->UpdateProgress( (m_Count + po->GetProgress()) /
                              m_NumberOfFilters);
    if (po->GetProgress() == 1.0) m_Count += 1.0;
    }
}

void WatershedMiniPipelineProgressCommand
::Execute(const Object *caller, const EventObject &event)
{
  ProcessObject *po = dynamic_cast<ProcessObject *>(const_cast<Object *>(caller));
  if (! po) return;
  
  if( typeid(event) == typeid ( ProgressEvent)  )
    {
    m_Filter->UpdateProgress( (m_Count + po->GetProgress()) /
                              m_NumberOfFilters);
    if (po->GetProgress() == 1.0) m_Count += 1.0;
    }
}

void WatershedMiniPipelineProgressCommand
::PrintSelf(std::ostream& os, Indent indent) const
{
  Superclass::PrintSelf(os,indent);
  os << indent << "NumberOfFilters: " << m_NumberOfFilters << std::endl;
  os << indent << "Count: " << m_Count << std::endl;
}
} // end namespace itk

==> insighttoolkit_3.18.0.orig.tar.gz: insighttoolkit-3.18.0/Code/Algorithms/itkWatershedMiniPipelineProgressCommand.cxx <==
/*=========================================================================

  Program:   Insight Segmentation & Registration Toolkit
  Module:    $RCSfile: itkWatershedMiniPipelineProgressCommand.cxx,v $
  Language:  C++
  Date:      $Date: 2009-11-28 16:23:24 $
  Version:   $Revision: 1.6 $

  Copyright (c) Insight Software Consortium. All rights reserved.
  See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.

     This software is distributed WITHOUT ANY WARRANTY; without even 
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
     PURPOSE.  See the above copyright notices for more information.

=========================================================================*/
#include "itkWatershedMiniPipelineProgressCommand.h"


namespace itk {

void WatershedMiniPipelineProgressCommand
::Execute(Object *caller, const EventObject &event)
{
  ProcessObject *po = dynamic_cast<ProcessObject *>(caller);
  if (! po) return;
  
  if( typeid(event) == typeid ( ProgressEvent)  )
    {
    m_Filter->UpdateProgress( 
      static_cast<float>( (m_Count + po->GetProgress()) / m_NumberOfFilters ));
    if( po->GetProgress() == 1.0 )
      {
      m_Count += 1.0;
      }
    }
}

void WatershedMiniPipelineProgressCommand
::Execute(const Object *caller, const EventObject &event)
{
  ProcessObject *po = dynamic_cast<ProcessObject *>(const_cast<Object *>(caller));
  if (! po) return;
  
  if( typeid(event) == typeid ( ProgressEvent)  )
    {
    m_Filter->UpdateProgress( 
      static_cast<float>( (m_Count + po->GetProgress()) / m_NumberOfFilters) );
    if (po->GetProgress() == 1.0)
      {
      m_Count += 1.0;
      }
    }
}

void WatershedMiniPipelineProgressCommand
::PrintSelf(std::ostream& os, Indent indent) const
{
  Superclass::PrintSelf(os,indent);
  os << indent << "NumberOfFilters: " << m_NumberOfFilters << std::endl;
  os << indent << "Count: " << m_Count << std::endl;
}
} // end namespace itk
